﻿using ComPDFKitViewer.PdfViewer;
using PDF_Office.CustomControl;
using PDF_Office.Helper;
using PDF_Office.Model;
using PDF_Office.Model.Dialog.ConverterDialogs;
using Prism.Commands;
using Prism.Mvvm;
using Prism.Services.Dialogs;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Windows.Forms;
using DialogResult = Prism.Services.Dialogs.DialogResult;

namespace PDF_Office.ViewModels.Dialog.ConverterDialogs
{
    public class ConverterImgDialogViewModel : BindableBase, IDialogAware
    {
        public ConverterImgDialogModel ConverterImgModel = new ConverterImgDialogModel();

        public CPDFViewer currentViewer;

        public IDialogService dialogs;

        public string PageRangeText { set; get; } = "0";

        public string PageRangeSelectIndex { set; get; } = "0";

        public List<string> ImageTypeFamily { set; get; } =new List<string>();

        private void SetImageTypeOrigin()
        {
            this.ImageTypeFamily.Add("JPEG");
            this.ImageTypeFamily.Add("JPG");
            this.ImageTypeFamily.Add("PNG");
            this.ImageTypeFamily.Add("GIF");
            this.ImageTypeFamily.Add("TIFF");
            this.ImageTypeFamily.Add("TGA");
            this.ImageTypeFamily.Add("BMP");
            this.ImageTypeFamily.Add("JPEG-2000");
        }

        public List<string> ImageDPIFamily { set; get; } = new List<string>();
        private void SetImageDPIOrigin()
        {
            this.ImageDPIFamily.Add("50 dpi");
            this.ImageDPIFamily.Add("72 dpi");
            this.ImageDPIFamily.Add("96 dpi");
            this.ImageDPIFamily.Add("150 dpi");
            this.ImageDPIFamily.Add("300 dpi");
            this.ImageDPIFamily.Add("600 dpi");
        }

        public DelegateCommand CancelCommand { get; set; }

        public DelegateCommand ConverterCommnad { get; set; }
        public ConverterImgDialogViewModel(IDialogService dialogService)
        {
            CancelCommand = new DelegateCommand(cancel);
            ConverterCommnad = new DelegateCommand(converter);
            dialogs = dialogService;
        }
        private void cancel()
        {
            RequestClose.Invoke(new DialogResult(ButtonResult.Cancel));
        }

        private  void converter()
        {
            FolderBrowserDialog dlg = new FolderBrowserDialog();
            if (dlg.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                ConverterImgModel.OutputPath = dlg.SelectedPath.Trim();
            }
            HomePageEditHelper.GetPagerange(PageRangeSelectIndex, currentViewer, ref ConverterImgModel.PageRange, PageRangeText, true);
            char[] enumerationSeparator = new char[] { ',' };
            char[] rangeSeparator = new char[] { '-' };
            if (!CommonHelper.GetPagesInRange(ref ConverterImgModel.PageIndexLists, ConverterImgModel.PageRange, currentViewer.Document.PageCount, enumerationSeparator, rangeSeparator))
            { //TODO
                Trace.WriteLine("输入不对");
                MessageBoxEx.Show("输入不对");
                return;
            }
           
            DialogParameters value = new DialogParameters();
            value.Add(ParameterNames.ConverterType, "Img");
            value.Add(ParameterNames.ConverterTypeModel, ConverterImgModel);
            RequestClose?.Invoke(new DialogResult(ButtonResult.OK));
            dialogs.ShowDialog(DialogNames.ConverterProgressBarDialog, value, e =>
            {

            });
        }

        private void SetProgress(int pageIndex)
        {

        }
        public string Title => "";

        public event Action<IDialogResult> RequestClose;

        public bool CanCloseDialog()
        {
            return true;
        }

        public void OnDialogClosed()
        {
        }

        public void OnDialogOpened(IDialogParameters parameters)
        {
            CPDFViewer pdfViewer = null;
            parameters.TryGetValue<CPDFViewer>(ParameterNames.PDFViewer, out pdfViewer);
            if (pdfViewer != null)
            {
                currentViewer = pdfViewer;
                ConverterImgModel.InputPath = pdfViewer.Document.FilePath;
                FileInfo fileinfo = new FileInfo(ConverterImgModel.InputPath);
                ConverterImgModel.OutputPath = fileinfo.DirectoryName;
                SetImageTypeOrigin();
                SetImageDPIOrigin();
            }
        }
    }
}
