﻿using ComPDFKitViewer.PdfViewer;
using PDF_Office.CustomControl;
using PDF_Office.Helper;
using PDF_Office.Model;
using PDF_Office.Model.Dialog.ConverterDialogs;
using Prism.Commands;
using Prism.Mvvm;
using Prism.Services.Dialogs;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Windows.Forms;
using DialogResult = Prism.Services.Dialogs.DialogResult;

namespace PDF_Office.ViewModels.Dialog.ConverterDialogs
{
    public class ConverterWordDialogViewModel : BindableBase, IDialogAware
    {
        public ConverterWordDialogModel ConverterWordModel = new ConverterWordDialogModel();

        public CPDFViewer currentViewer;

        public IDialogService dialogs;

        public string PageRangeText { set; get; } = "0";

        public string PageRangeSelectIndex { set; get; } = "0";

        public DelegateCommand<string> RadioButtonCommand { get; set; }

        public DelegateCommand CancelCommand { get; set; }

        public DelegateCommand ConverterCommnad { get; set; }

        public ConverterWordDialogViewModel(IDialogService dialogService)
        {
            CancelCommand = new DelegateCommand(cancel);
            ConverterCommnad = new DelegateCommand(converter);
            RadioButtonCommand = new DelegateCommand<string>(radiobutton);
            dialogs = dialogService;
        }
        private void cancel()
        {
            RequestClose.Invoke(new DialogResult(ButtonResult.Cancel));
        }

        private void converter()
        {
            FolderBrowserDialog dlg = new FolderBrowserDialog();
            if (dlg.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                ConverterWordModel.OutputPath = dlg.SelectedPath.Trim();
            }
            HomePageEditHelper.GetPagerange(PageRangeSelectIndex, currentViewer, ref ConverterWordModel.PageRange, PageRangeText, true);
            char[] enumerationSeparator = new char[] { ',' };
            char[] rangeSeparator = new char[] { '-' };
            if (!CommonHelper.GetPagesInRange(ref ConverterWordModel.PageIndexLists, ConverterWordModel.PageRange, currentViewer.Document.PageCount, enumerationSeparator, rangeSeparator))
            { //TODO
                MessageBoxEx.Show("输入不对");
                return;
            }
            
            DialogParameters value = new DialogParameters();
            value.Add(ParameterNames.ConverterType, "Word");
            value.Add(ParameterNames.ConverterTypeModel, ConverterWordModel);
            RequestClose?.Invoke(new DialogResult(ButtonResult.OK));
            dialogs.ShowDialog(DialogNames.ConverterProgressBarDialog, value, e =>
            {

            });
        }

        private void radiobutton(string e)
        {
            string radioButton = e;
            if (radioButton != null)
            {
                switch (radioButton)
                {
                    case "FlowingTextRadioBtn":
                        break;
                    case "PageLayoutRadioBtn":
                        break;
                    default:
                        break;
                }
            }

        }

        private void SetProgress(int pageIndex)
        {

        }
        public string Title => "";

        public event Action<IDialogResult> RequestClose;

        public bool CanCloseDialog()
        {
            return true;
        }

        public void OnDialogClosed()
        {
        }

        public void OnDialogOpened(IDialogParameters parameters)
        {
            CPDFViewer pdfViewer = null;
            parameters.TryGetValue<CPDFViewer>(ParameterNames.PDFViewer, out pdfViewer);
            if (pdfViewer != null)
            {
                currentViewer = pdfViewer;
                ConverterWordModel.InputPath = pdfViewer.Document.FilePath;
                FileInfo fileinfo = new FileInfo(ConverterWordModel.InputPath);
                ConverterWordModel.OutputPath = fileinfo.DirectoryName;
            }
        }
    }
}
